#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_RSHR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_RSHR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/rshr.hpp>

#endif
